Learn R Programming

bioregion (version 1.3.0)

betapart_to_bioregion: Convert betapart dissimilarity to bioregion dissimilarity (DEPRECATED)

Description

This function converts dissimilarity results produced by the betapart package (and packages using betapart, such as phyloregion) into a dissimilarity object compatible with the bioregion package. This function only converts object types to make them compatible with bioregion; it does not modify the beta-diversity values. This function allows the inclusion of phylogenetic beta diversity to compute bioregions with bioregion.

Usage

betapart_to_bioregion(betapart_result)

Value

A dissimilarity object of class bioregion.pairwise, compatible with the bioregion package.

Arguments

betapart_result

An object produced by the betapart package (e.g., using the beta.pair function).

Author

Boris Leroy (leroy.boris@gmail.com)
Maxime Lenormand (maxime.lenormand@inrae.fr)
Pierre Denelle (pierre.denelle@gmail.com)

See Also

This function is deprecated, use as_bioregion_pairwise instead.

Examples

Run this code
comat <- matrix(sample(0:1000, size = 50, replace = TRUE,
prob = 1 / 1:1001), 5, 10)
rownames(comat) <- paste0("Site", 1:5)
colnames(comat) <- paste0("Species", 1:10)

if (FALSE) {
beta_div <- betapart::beta.pair.abund(comat)
betapart_to_bioregion(beta_div)
}

Run the code above in your browser using DataLab