View source: R/bioregion_metrics.R
| bioregion_metrics | R Documentation |
This function calculates the number of sites, the number of species, the number of endemic species and the proportion of endemism per bioregion. The spatial coherence can be optionally computed if a spatial object is provided.
bioregion_metrics(bioregionalization, comat, map = NULL, col_bioregion = NULL)
bioregionalization |
A |
comat |
A site-species |
map |
A spatial object that can be handled by |
col_bioregion |
Deprecated. |
map should be the output of
map_bioregions(bioregionalization, geometry, write_clusters = TRUE)
A data.frame with 5 columns (Bioregion ID and metrics described below) or
7 if spatial coherence is computed.
NbSites: Number of sites per bioregion
Richness: Number of distinct species per bioregion.
Rich_Endemics: Number of species found only in the bioregion.
Prop_Endemics: Fraction of endemics species.
SC_size: Spatial coherence based on size, fraction of the number of site contained in the bioregion's largest contiguous patch.
SC_area: Spatial coherence based on area, fraction of the bioregion area contained in its largest contiguous patch.
Note that if bioregionalization contains multiple partitions
(i.e., if dim(bioregionalization$clusters) > 2), a list will be
returned.
Pierre Denelle (pierre.denelle@gmail.com)
Boris Leroy (leroy.boris@gmail.com)
Maxime Lenormand (maxime.lenormand@inrae.fr)
For more details illustrated with a practical example, see the vignette: https://biorgeo.github.io/bioregion/articles/a5_2_summary_metrics.html.
Associated functions: site_species_metrics bioregionalization_metrics
comat <- matrix(sample(1000, 50), 5, 10)
rownames(comat) <- paste0("Site", 1:5)
colnames(comat) <- paste0("Species", 1:10)
net <- similarity(comat, metric = "Simpson")
clust <- netclu_louvain(net)
bioregion_metrics(bioregionalization = clust,
comat = comat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.