With a the number of species shared by a pair of sites, b species only
present in the first site and c species only present in the second site.
Jaccard = (b + c) / (a + b + c)Jaccard = (b + c) / (a + b + c)
Jaccardturn = 2min(b, c) / (a + 2min(b, c))Jaccardturn = 2min(b, c) / (a + 2min(b, c))Baselga2012bioregion
Sorensen = (b + c) / (2a + b + c)Sorensen = (b + c) / (2a + b + c)
Simpson = min(b, c) / (a + min(b, c))Simpson = min(b, c) / (a + min(b, c))
If abundances data are available, Bray-Curtis and its turnover component
can also be computed with the following equation:
Bray = (B + C) / (2A + B + C)Bray = (B + C) / (2A + B + C)
Brayturn = min(B, C)/(A + min(B, C))Brayturn = min(B, C)/(A + min(B, C)) Baselga2013bioregion
with A the sum of the lesser values for common species shared by a pair of
sites. B and C are the total number of specimens counted at both sites minus
A.
formula can be used to compute customized metrics with the terms
a, b, c, A, B, and C. For example
formula = c("pmin(b,c) / (a + pmin(b,c))", "(B + C) / (2*A + B + C)")
will compute the Simpson and Bray-Curtis dissimilarity metrics, respectively.
Note that pmin is used in the Simpson formula because a, b, c, A, B and C
are numeric vectors.
Euclidean computes the Euclidean distance between each pair of sites.