This function takes a bipartite weighted graph and computes modules by applying Newman’s modularity measure in a bipartite weighted version.
netclu_beckett(
net,
weight = TRUE,
cut_weight = 0,
index = names(net)[3],
seed = NULL,
forceLPA = FALSE,
site_col = 1,
species_col = 2,
return_node_type = "both",
algorithm_in_output = TRUE
)A list of class bioregion.clusters with five slots:
name: A character containing the name of the algorithm.
args: A list of input arguments as provided by the user.
inputs: A list of characteristics of the clustering process.
algorithm: A list of all objects associated with the
clustering procedure, such as original cluster objects (only if
algorithm_in_output = TRUE).
clusters: A data.frame containing the clustering results.
If algorithm_in_output = TRUE, users can find the output of
computeModules in the algorithm slot.
A data.frame representing a bipartite network with the first
two columns representing undirected links between pairs of nodes, and the
next column(s) representing the weights of the links.
A boolean indicating whether weights should be considered
if there are more than two columns (see Note).
A minimal weight value. If weight is TRUE, links
with weights strictly lower than this value will not be considered
(0 by default).
The name or number of the column to use as weight. By default,
the third column name of net is used.
The seed for the random number generator (NULL for random
by default).
A boolean indicating whether the even faster pure
LPA-algorithm of Beckett should be used. DIRT-LPA (the default) is less
likely to get trapped in a local minimum but is slightly slower. Defaults
to FALSE.
The name or number of the column for site nodes (i.e., primary nodes).
The name or number of the column for species nodes (i.e., feature nodes).
A character indicating which types of nodes
("site", "species", or "both") should be returned in the output
("both" by default).
A boolean indicating whether the original
output of computeModules should be returned
in the output (TRUE by default, see Value).
Maxime Lenormand (maxime.lenormand@inrae.fr)
Pierre Denelle (pierre.denelle@gmail.com)
Boris Leroy (leroy.boris@gmail.com)
This function is based on the modularity optimization algorithm provided by Stephen Beckett (Beckett, 2016) as implemented in the bipartite package (computeModules).
Beckett SJ (2016) Improved community detection in weighted bipartite networks. Royal Society Open Science 3, 140536.
For more details illustrated with a practical example, see the vignette: https://biorgeo.github.io/bioregion/articles/a4_3_network_clustering.html.
Associated functions: netclu_infomap netclu_louvain netclu_oslom
net <- data.frame(
Site = c(rep("A", 2), rep("B", 3), rep("C", 2)),
Species = c("a", "b", "a", "c", "d", "b", "d"),
Weight = c(10, 100, 1, 20, 50, 10, 20))
com <- netclu_beckett(net)
Run the code above in your browser using DataLab