This function takes a bipartite weighted graph and computes modules by applying Newman’s modularity measure in a bipartite weighted version to it.
netclu_beckett(
net,
weight = TRUE,
cut_weight = 0,
index = names(net)[3],
seed = NULL,
forceLPA = FALSE,
site_col = 1,
species_col = 2,
return_node_type = "both",
algorithm_in_output = TRUE
)A list of class bioregion.clusters with five slots:
name: character containing the name of the algorithm
args: list of input arguments as provided by the user
inputs: list of characteristics of the clustering process
algorithm: list of all objects associated with the
clustering procedure, such as original cluster objects (only if
algorithm_in_output = TRUE)
clusters: data.frame containing the clustering results
In the algorithm slot, if algorithm_in_output = TRUE, users can find the
output of computeModules.
a data.frame representing a bipartite network with the two
first columns as undirected links between pair of nodes and and the next
column(s) are the weight of the links.
a boolean indicating if the weights should be considered
if there are more than two columns (see Note).
a minimal weight value. If weight is TRUE, the links
between sites with a weight strictly lower than this value will not be
considered (O by default).
name or number of the column to use as weight. By default,
the third column name of net is used.
for the random number generator (NULL for random by default).
a boolean indicating if the even faster pure
LPA-algorithm of Beckett should be used? DIRT-LPA, the default, is less
likely to get trapped in a local minimum, but is slightly slower. Defaults
to FALSE.
name or number for the column of site nodes (i.e. primary nodes).
name or number for the column of species nodes (i.e. feature nodes).
a character indicating what types of nodes
(site, species or both) should be returned in the output
(return_node_type = "both" by default).
a boolean indicating if the original output
of computeModules should be returned in the
output (TRUE by default, see Value).
Maxime Lenormand (maxime.lenormand@inrae.fr), Pierre Denelle (pierre.denelle@gmail.com) and Boris Leroy (leroy.boris@gmail.com)
This function is based on the modularity optimization algorithm provided by Stephen Beckett Beckett2016bioregion as implemented in the bipartite package (computeModules).
Beckett2016bioregion
netclu_infomap, netclu_oslom
net <- data.frame(
Site = c(rep("A", 2), rep("B", 3), rep("C", 2)),
Species = c("a", "b", "a", "c", "d", "b", "d"),
Weight = c(10, 100, 1, 20, 50, 10, 20))
com <- netclu_beckett(net)
Run the code above in your browser using DataLab