This function finds communities in a (un)weighted (un)directed network based on the Infomap algorithm (https://github.com/mapequation/infomap).
netclu_infomap(
net,
weight = TRUE,
cut_weight = 0,
index = names(net)[3],
seed = NULL,
nbmod = 0,
markovtime = 1,
numtrials = 1,
twolevel = FALSE,
show_hierarchy = FALSE,
directed = FALSE,
bipartite_version = FALSE,
bipartite = FALSE,
site_col = 1,
species_col = 2,
return_node_type = "both",
version = "2.7.1",
binpath = "tempdir",
path_temp = "infomap_temp",
delete_temp = TRUE
)A list of class bioregion.clusters with five slots:
name: character containing the name of the algorithm
args: list of input arguments as provided by the user
inputs: list of characteristics of the clustering process
algorithm: list of all objects associated with the
clustering procedure, such as original cluster objects
clusters: data.frame containing the clustering results
In the algorithm slot, users can find the following elements:
cmd: the command line use to run Infomap
version: the Infomap version
web: Infomap's GitHub repository
the output object from similarity() or
dissimilarity_to_similarity().
If a data.frame is used, the first two columns represent pairs of
sites (or any pair of nodes), and the next column(s) are the similarity
indices.
a boolean indicating if the weights should be considered
if there are more than two columns.
a minimal weight value. If weight is TRUE, the links
between sites with a weight strictly lower than this value will not be
considered (O by default).
name or number of the column to use as weight. By default,
the third column name of net is used.
for the random number generator (NULL for random by default).
penalize solutions the more they differ from this number (0 by default for no preferred number of modules).
scales link flow to change the cost of moving between modules, higher values results in fewer modules (default is 1).
for the number of trials before picking up the best solution.
a boolean indicating if the algorithm should optimize a
two-level partition of the network (default is multi-level).
a boolean specifying if the hierarchy of community
should be identifiable in the outputs (FALSE by default).
a boolean indicating if the network is directed (from
column 1 to column 2).
a boolean indicating if the bipartite version of
Infomap should be used (see Note).
a boolean indicating if the network is bipartite
(see Note).
name or number for the column of site nodes (i.e. primary nodes).
name or number for the column of species nodes (i.e. feature nodes).
a character indicating what types of nodes
(site, species or both) should be returned in the output
(return_node_type = "both" by default).
a character indicating the Infomap version to use.
a character indicating the path to the bin folder
(see install_binaries and Details).
a character indicating the path to the temporary folder
(see Details).
a boolean indicating if the temporary folder should
be removed (see Details).
Maxime Lenormand (maxime.lenormand@inrae.fr), Pierre Denelle (pierre.denelle@gmail.com) and Boris Leroy (leroy.boris@gmail.com)
Infomap is a network clustering algorithm based on the Map equation proposed in Rosvall2008bioregion that finds communities in (un)weighted and (un)directed networks.
This function is based on the C++ version of Infomap (https://github.com/mapequation/infomap/releases). This function needs binary files to run. They can be installed with install_binaries.
If you changed the default path to the bin folder
while running install_binaries PLEASE MAKE SURE to set binpath
accordingly.
The C++ version of Infomap generates temporary folders and/or files that are
stored in the path_temp folder ("infomap_temp" with an unique timestamp
located in the bin folder in binpath by default). This temporary folder is
removed by default (delete_temp = TRUE).
Several version of Infomap are available in the package. See install_binaries for more details.
Rosvall2008bioregion
install_binaries, netclu_louvain, netclu_oslom
comat <- matrix(sample(1000, 50), 5, 10)
rownames(comat) <- paste0("Site", 1:5)
colnames(comat) <- paste0("Species", 1:10)
net <- similarity(comat, metric = "Simpson")
com <- netclu_infomap(net)
Run the code above in your browser using DataLab