This function finds communities in a (un)weighted undirected network based on the Louvain algorithm.
netclu_louvain(
net,
weight = TRUE,
cut_weight = 0,
index = names(net)[3],
lang = "igraph",
resolution = 1,
seed = NULL,
q = 0,
c = 0.5,
k = 1,
bipartite = FALSE,
site_col = 1,
species_col = 2,
return_node_type = "both",
binpath = "tempdir",
check_install = TRUE,
path_temp = "louvain_temp",
delete_temp = TRUE,
algorithm_in_output = TRUE
)A list of class bioregion.clusters with five slots:
name: A character containing the name of the algorithm.
args: A list of input arguments as provided by the user.
inputs: A list of characteristics of the clustering process.
algorithm: A list of all objects associated with the
clustering procedure, such as original cluster objects (only if
algorithm_in_output = TRUE).
clusters: A data.frame containing the clustering results.
In the algorithm slot, if algorithm_in_output = TRUE, users can
find the output of cluster_louvain if
lang = "igraph" and the following element if lang = "cpp":
cmd: The command line used to run Louvain.
version: The Louvain version.
web: The Louvain's website.
The output object from similarity() or
dissimilarity_to_similarity().
If a data.frame is used, the first two columns represent pairs of sites
(or any pair of nodes), and the next column(s) are the similarity indices.
A boolean indicating if the weights should be considered
if there are more than two columns.
A minimal weight value. If weight is TRUE, the links
between sites with a weight strictly lower than this value will not be
considered (0 by default).
The name or number of the column to use as weight. By default,
the third column name of net is used.
A string indicating which version of Louvain should be used
("igraph" or "cpp", see Details).
A resolution parameter to adjust the modularity (1 is chosen by default, see Details).
The random number generator seed (only when lang = "igraph",
NULL for random by default).
The quality function used to compute the partition of the graph (modularity is chosen by default, see Details).
The parameter for the Owsinski-Zadrozny quality function (between 0 and 1, 0.5 is chosen by default).
The kappa_min value for the Shi-Malik quality function (it must be > 0, 1 is chosen by default).
A boolean indicating if the network is bipartite
(see Details).
The name or number for the column of site nodes (i.e., primary nodes).
The name or number for the column of species nodes (i.e., feature nodes).
A character indicating what types of nodes
("site", "species", or "both") should be returned in the output
("both" by default).
A character indicating the path to the bin folder
(see install_binaries and Details).
A boolean indicating if the function should check that
Louvain has been properly installed (see install_binaries and Details).
A character indicating the path to the temporary folder
(see Details).
A boolean indicating if the temporary folder should
be removed (see Details).
A boolean indicating if the original output
of cluster_louvain should be returned in the
output (TRUE by default, see Value).
Maxime Lenormand (maxime.lenormand@inrae.fr)
Pierre Denelle (pierre.denelle@gmail.com)
Boris Leroy (leroy.boris@gmail.com)
Louvain is a network community detection algorithm proposed in
(Blondel et al., 2008). This function offers two
implementations of the Louvain algorithm (controlled by the lang parameter):
the igraph
implementation (cluster_louvain) and the C++
implementation (https://sourceforge.net/projects/louvain/, version 0.3).
The igraph
implementation allows adjustment of the resolution parameter of
the modularity function (resolution argument) used internally by the
algorithm. Lower values typically yield fewer, larger clusters. The original
definition of modularity is recovered when the resolution parameter
is set to 1 (by default).
The C++ implementation provides several quality functions:
q = 0 for the classical Newman-Girvan criterion (Modularity),
q = 1 for the Zahn-Condorcet criterion, q = 2 for the Owsinski-Zadrozny
criterion (parameterized by c), q = 3 for the Goldberg Density criterion,
q = 4 for the A-weighted Condorcet criterion, q = 5 for the Deviation to
Indetermination criterion, q = 6 for the Deviation to Uniformity criterion,
q = 7 for the Profile Difference criterion, q = 8 for the Shi-Malik
criterion (parameterized by k), and q = 9 for the Balanced Modularity
criterion.
The C++ version is based on version 0.3 (https://sourceforge.net/projects/louvain/). Binary files are required to run it, and can be installed with install_binaries.
If you changed the default path to the bin folder
while running install_binaries, PLEASE MAKE SURE to set binpath
accordingly.
If you did not use install_binaries to change the permissions or test
the binary files, PLEASE MAKE SURE to set check_install accordingly.
The C++ version generates temporary folders and/or files in the path_temp
folder ("louvain_temp" with a unique timestamp located in the bin folder in
binpath by default). This temporary folder is removed by default
(delete_temp = TRUE).
Blondel VD, Guillaume JL, Lambiotte R & Mech ELJS (2008) Fast unfolding of communities in large networks. J. Stat. Mech. 10, P10008.
For more details illustrated with a practical example, see the vignette: https://biorgeo.github.io/bioregion/articles/a4_3_network_clustering.html.
Associated functions: netclu_infomap netclu_greedy netclu_oslom
comat <- matrix(sample(1000, 50), 5, 10)
rownames(comat) <- paste0("Site", 1:5)
colnames(comat) <- paste0("Species", 1:10)
net <- similarity(comat, metric = "Simpson")
com <- netclu_louvain(net, lang = "igraph")
Run the code above in your browser using DataLab