This function finds communities in a (un)weighted (un)directed network based on the OSLOM algorithm (http://oslom.org/, version 2.4).
netclu_oslom(
net,
weight = TRUE,
cut_weight = 0,
index = names(net)[3],
seed = NULL,
reassign = "no",
r = 10,
hr = 50,
t = 0.1,
cp = 0.5,
directed = FALSE,
bipartite = FALSE,
site_col = 1,
species_col = 2,
return_node_type = "both",
binpath = "tempdir",
check_install = TRUE,
path_temp = "oslom_temp",
delete_temp = TRUE
)A list of class bioregion.clusters with five slots:
name: A character containing the name of the algorithm.
args: A list of input arguments as provided by the user.
inputs: A list of characteristics of the clustering process.
algorithm: A list of all objects associated with the
clustering procedure, such as original cluster objects (only if
algorithm_in_output = TRUE).
clusters: A data.frame containing the clustering results.
In the algorithm slot, users can find the following elements:
cmd: The command line used to run OSLOM.
version: The OSLOM version.
web: The OSLOM's web site.
The output object from similarity() or
dissimilarity_to_similarity().
If a data.frame is used, the first two columns represent pairs of
sites (or any pair of nodes), and the next column(s) are the similarity
indices.
A boolean indicating if the weights should be considered
if there are more than two columns.
A minimal weight value. If weight is TRUE, the links
between sites with a weight strictly lower than this value will not be
considered (0 by default).
Name or number of the column to use as weight. By default,
the third column name of net is used.
For the random number generator (NULL for random by default).
A character indicating if the nodes belonging to several
community should be reassigned and what method should be used (see Note).
The number of runs for the first hierarchical level (10 by default).
The number of runs for the higher hierarchical level (50 by default, 0 if you are not interested in hierarchies).
The p-value, the default value is 0.10. Increase this value if you want more modules.
Kind of resolution parameter used to decide between taking some modules or their union (default value is 0.5; a bigger value leads to bigger clusters).
A boolean indicating if the network is directed (from
column 1 to column 2).
A boolean indicating if the network is bipartite
(see Details).
Name or number for the column of site nodes (i.e. primary nodes).
Name or number for the column of species nodes (i.e. feature nodes).
A character indicating what types of nodes
(site, species, or both) should be returned in the output
(return_node_type = "both" by default).
A character indicating the path to the bin folder
(see install_binaries and Details).
A boolean indicating if the function should check that
the OSLOM has been properly installed (see install_binaries and Details).
A character indicating the path to the temporary folder
(see Details).
A boolean indicating if the temporary folder should
be removed (see Details).
Maxime Lenormand (maxime.lenormand@inrae.fr)
Pierre Denelle (pierre.denelle@gmail.com)
Boris Leroy (leroy.boris@gmail.com)
OSLOM is a network community detection algorithm proposed in Lancichinetti et al. (2011) that finds statistically significant (overlapping) communities in (un)weighted and (un)directed networks.
This function is based on the 2.4 C++ version of OSLOM (http://www.oslom.org/software.htm). This function needs files to run. They can be installed with install_binaries.
If you changed the default path to the bin folder
while running install_binaries, PLEASE MAKE SURE to set binpath
accordingly.
If you did not use install_binaries to change the permissions and test
the binary files, PLEASE MAKE SURE to set check_install accordingly.
The C++ version of OSLOM generates temporary folders and/or files that are
stored in the path_temp folder (folder "oslom_temp" with a unique timestamp
located in the bin folder in binpath by default). This temporary folder is
removed by default (delete_temp = TRUE).
Lancichinetti A, Radicchi F, Ramasco JJ & Fortunato S (2011) Finding statistically significant communities in networks. PLOS ONE 6, e18961.
For more details illustrated with a practical example, see the vignette: https://biorgeo.github.io/bioregion/articles/a4_3_network_clustering.html.
Associated functions: netclu_greedy netclu_infomap netclu_louvain
comat <- matrix(sample(1000, 50), 5, 10)
rownames(comat) <- paste0("Site", 1:5)
colnames(comat) <- paste0("Species", 1:10)
net <- similarity(comat, metric = "Simpson")
com <- netclu_oslom(net)
Run the code above in your browser using DataLab