View source: R/site_species_subset.R
| site_species_subset | R Documentation |
bioregion.clusters objectThis function extracts a subset of nodes based on their type ("site" or
"species") from a bioregion.clusters object, which contains both types of
nodes (sites and species).
site_species_subset(bioregionalization, node_type = "site", clusters = NULL)
bioregionalization |
An object of class |
node_type |
A |
clusters |
Deprecated. Use |
An object of class bioregion.clusters containing only the specified
node type (sites or species).
Some bioregion.clusters objects may contain both types of nodes (sites and
species). This information is available in the $inputs$node_type slot.
This function allows you to extract a specific type of node
(either sites or species) from any bioregion.clusters object that
includes both.
Maxime Lenormand (maxime.lenormand@inrae.fr)
Pierre Denelle (pierre.denelle@gmail.com)
Boris Leroy (leroy.boris@gmail.com)
net <- data.frame(
Site = c(rep("A", 2), rep("B", 3), rep("C", 2)),
Species = c("a", "b", "a", "c", "d", "b", "d"),
Weight = c(10, 100, 1, 20, 50, 10, 20)
)
clu <- netclu_louvain(net, lang = "igraph", bipartite = TRUE)
clu_sites <- site_species_subset(clu, node_type = "site")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.